import {
  IonContent,
  IonHeader,
  IonPage,
  IonTitle,
  IonToast,
  IonToolbar,
} from "@ionic/react";
import { alertCircleOutline } from "ionicons/icons";
import useSWR from "swr";
import TopicList from "../components/TopicList";
import { fetcher } from "../lib/api";
import { Topic } from "../types";

const AdviceListPage: React.FC = () => {
  const { data: paternidad, error: paternidadError } = useSWR<Topic[]>(
    "/api/getTopicList?type=advice&category=Paternidad",
    fetcher
  );
  const { data: matrimonio, error: matrimonioError } = useSWR<Topic[]>(
    "/api/getTopicList?type=advice&category=Matrimonio",
    fetcher
  );
  const { data: abuso, error: abusoError } = useSWR<Topic[]>(
    "/api/getTopicList?type=advice&category=Abuso%20Sexual",
    fetcher
  );
  const error = paternidadError || matrimonioError || abusoError;

  return (
    <IonPage>
      <IonHeader>
        <IonToolbar>
          <IonTitle>Advice</IonTitle>
        </IonToolbar>
      </IonHeader>
      <IonContent fullscreen>
        <IonHeader collapse="condense">
          <IonToolbar>
            <IonTitle size="large">Advice</IonTitle>
          </IonToolbar>
        </IonHeader>
        <TopicList
          title="Paternidad"
          loading={!paternidad && !paternidadError}
          topics={paternidad ? (paternidad as Topic[]) : []}
        />
        <TopicList
          title="Matrimonio"
          loading={!matrimonio && !matrimonioError}
          topics={matrimonio ? (matrimonio as Topic[]) : []}
        />
        <TopicList
          title="Abuso Sexual"
          loading={!abuso && !abusoError}
          topics={abuso ? (abuso as Topic[]) : []}
        />
        <IonToast
          icon={alertCircleOutline}
          color="danger"
          isOpen={error !== undefined}
          message="Failed to load items."
          duration={1500}
        />
      </IonContent>
    </IonPage>
  );
};

export default AdviceListPage;
